Introduction — Ryser 0.0.10 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Ryser 0.0.10 documentation »

# Introduction

Ryser is a Python package for modelling latin squares and related combinatorial designs. The author is especially interested in specializations of latin squares, notably Gerechte designs and Sudoku puzzles. Other structures of interest are Room squares and magic squares.

In fact, as well as providing models, and thus exposing the algorithms of those different domains, we also provide direct access to the structures, thus enabling the construction of direct algorithms.

### Navigation

- index
- modules |
- next |
- previous |
- Ryser 0.0.10 documentation »